@@ -908,7 +908,7 @@ class ClbClient(AbstractClient):
 
 
     def DescribeLoadBalancerTraffic(self, request):
-        """This API is used to query CLB instances with high traffic and return the top 10 results. For queries using a sub-account, only the result CLB instances authorized to the sub-account will be returned.
+        """This API is used to query CLB instances with high traffic under the current account, and return the top 10 results. For queries using a sub-account, only the CLB instances authorized to the sub-account will be returned.
 
         :param request: Request instance for DescribeLoadBalancerTraffic.
         :type request: :class:`tencentcloud.clb.v20180317.models.DescribeLoadBalancerTrafficRequest`
